server_client_20150129_153254

### config1 : test_client_timeout

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 61.182199955 sec | 64.2207369804 sec

Error message: Did not properly handle client timeout

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 0.13 | 0.085 | 0.073 | 0.085 | 0.09 | 0.093 | 0.097 | 0.11 | 0.0077
qps | 951.00 | 500.50 | 50.00 | 500.50 | 725.75 | 860.90 | 905.95 | 941.99 | 450.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 901.14 | 901.14 | 901.14 | 901.14 | 901.14 | 901.14 | 901.14 | 901.14 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.085
server1-perf | latency | mean lt 0.33 | 0.0848361638362
server1-perf | qps | mean lt 7.0 | 500.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 901.135
client1-perf | latency | mean lt 35.0 | 901.135
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None